==> libksysguard-6.2.5.tgz: lib/cmake/KSysGuard/KSysGuardLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KSysGuard::Formatter" for configuration "Release"
set_property(TARGET KSysGuard::Formatter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Formatter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;KF6::CoreAddons;KF6::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardFormatter.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Formatter )
list(APPEND _cmake_import_check_files_for_KSysGuard::Formatter "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.1.0" )

# Import target "KSysGuard::ProcessCore" for configuration "Release"
set_property(TARGET KSysGuard::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KF6::AuthCore;KF6::CoreAddons;KF6::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libprocesscore.so.1.0"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::ProcessCore )
list(APPEND _cmake_import_check_files_for_KSysGuard::ProcessCore "${_IMPORT_PREFIX}/lib/libprocesscore.so.1.0" )

# Import target "KSysGuard::Sensors" for configuration "Release"
set_property(TARGET KSysGuard::Sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Sensors PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;KF6::I18n;KSysGuard::SystemStats"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensors.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Sensors )
list(APPEND _cmake_import_check_files_for_KSysGuard::Sensors "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.1.0" )

# Import target "KSysGuard::SensorFaces" for configuration "Release"
set_property(TARGET KSysGuard::SensorFaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SensorFaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;KF6::I18n;KF6::Package;KF6::ConfigQml;KF6::Solid"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensorFaces.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SensorFaces )
list(APPEND _cmake_import_check_files_for_KSysGuard::SensorFaces "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.1.0" )

# Import target "KSysGuard::SystemStats" for configuration "Release"
set_property(TARGET KSysGuard::SystemStats APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SystemStats PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardSystemStats.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardSystemStats.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SystemStats )
list(APPEND _cmake_import_check_files_for_KSysGuard::SystemStats "${_IMPORT_PREFIX}/lib/libKSysGuardSystemStats.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libksysguard-6.4.5.tgz: lib/cmake/KSysGuard/KSysGuardLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KSysGuard::Formatter" for configuration "Release"
set_property(TARGET KSysGuard::Formatter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Formatter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::CoreAddons;KF6::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardFormatter.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Formatter )
list(APPEND _cmake_import_check_files_for_KSysGuard::Formatter "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.1.0" )

# Import target "KSysGuard::ProcessCore" for configuration "Release"
set_property(TARGET KSysGuard::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KF6::AuthCore;KF6::CoreAddons;KF6::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libprocesscore.so.1.0"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::ProcessCore )
list(APPEND _cmake_import_check_files_for_KSysGuard::ProcessCore "${_IMPORT_PREFIX}/lib/libprocesscore.so.1.0" )

# Import target "KSysGuard::Sensors" for configuration "Release"
set_property(TARGET KSysGuard::Sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Sensors PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Core;Qt6::DBus;KF6::I18n;KSysGuard::SystemStats"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensors.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Sensors )
list(APPEND _cmake_import_check_files_for_KSysGuard::Sensors "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.1.0" )

# Import target "KSysGuard::SensorFaces" for configuration "Release"
set_property(TARGET KSysGuard::SensorFaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SensorFaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Core;Qt6::DBus;KF6::I18n;KF6::Package;KF6::ConfigQml;KF6::Solid"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensorFaces.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SensorFaces )
list(APPEND _cmake_import_check_files_for_KSysGuard::SensorFaces "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.1.0" )

# Import target "KSysGuard::SystemStats" for configuration "Release"
set_property(TARGET KSysGuard::SystemStats APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SystemStats PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKSysGuardSystemStats.so.1.0"
  IMPORTED_SONAME_RELEASE "libKSysGuardSystemStats.so.1.0"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SystemStats )
list(APPEND _cmake_import_check_files_for_KSysGuard::SystemStats "${_IMPORT_PREFIX}/lib/libKSysGuardSystemStats.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
